@@ -9,7 +9,14 @@ module ActiveRecord
       end
 
       def queries
-        [ associated_table.join_foreign_key => ids ]
+        if associated_table.join_foreign_key.is_a?(Array)
+          id_list = ids
+          id_list = id_list.pluck(primary_key) if id_list.is_a?(Relation)
+
+          id_list.map { |ids_set| associated_table.join_foreign_key.zip(ids_set).to_h }
+        else
+          [ associated_table.join_foreign_key => ids ]
+        end
       end
 
       private
@@ -25,7 +32,7 @@ module ActiveRecord
           when Array
             value.map { |v| convert_to_id(v) }
           else
-            convert_to_id(value)
+            [convert_to_id(value)]
           end
         end
 
@@ -50,6 +57,8 @@ module ActiveRecord
         end
 
         def convert_to_id(value)
+          return primary_key.map { |pk| value.public_send(pk) } if primary_key.is_a?(Array)
+
           if value.respond_to?(primary_key)
             value.public_send(primary_key)
           else
